/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.core;

import java.util.Collections;
import java.util.Map;

/**
 * Contains result of the project configuration.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class ConfigureResult
{
    /**
     * Builder for building {@link ConfigureResult} objects.
     *
     * @author htfv (Aliaksei Lahachou)
     */
    public static class Builder
    {
        private Map<String, Object> results;

        /**
         * Builds a new {@link ConfigureResult} object.
         *
         * @return a new {@link ConfigureResult} object.
         */
        public ConfigureResult build()
        {
            return new ConfigureResult(this);
        }

        public Builder results(final Map<String, Object> results)
        {
            this.results = results;
            return this;
        }
    }

    private final Map<String, Object> results;

    /**
     * Constructs a new {@link ConfigureResult} object.
     *
     * @param builder
     *            {@link Builder} containing parameters for construction.
     */
    protected ConfigureResult(final Builder builder)
    {
        this.results = Collections.unmodifiableMap(builder.results);
    }

    public <T> T getResult(final Class<T> resultType)
    {
        @SuppressWarnings("unchecked")
        final T result = (T) results.get(resultType.getName());

        return result;
    }
}
