/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.core;

import java.util.Map;

import org.codehaus.plexus.interpolation.AbstractValueSource;

/**
 * Supplies values for interpolation from a map.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class PropertiesValueSource extends AbstractValueSource
{
    /**
     * Map supplying properties for interpolation.
     */
    private final Map<String, String> properties;

    /**
     * Constructs a new {@link PropertiesValueSource} object.
     *
     * @param properties
     *            map supplying properties for interpolation.
     */
    public PropertiesValueSource(final Map<String, String> properties)
    {
        super(false);
        this.properties = properties;
    }

    @Override
    public Object getValue(final String expression)
    {
        return properties.get(expression);
    }
}
