/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.core.configuration;

import java.util.List;

/**
 * Contains parameters for configuring a project.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class BuildConfiguratorExtensionConfiguration implements BuildConfiguratorPluginConfiguration
{
    /**
     * Build information which shall be merged into the project.
     */
    private BuildConfiguration build;

    /**
     * Default character encoding used to read property files. Character
     * encoding may be overridden for each loaded property file.
     */
    private String defaultPropertyFilesEncoding;

    /**
     * Array of dependencies which shall be merged into the project.
     */
    private List<DependencyConfiguration> dependencies;

    /**
     * Flag indicating whether the plugin should be quiet when a property file
     * is not found.
     */
    private String ignoreMissingPropertyFiles;

    /**
     * Array of property files whose properties shall be merged into the
     * project.
     */
    private List<PropertyFileConfiguration> propertyFiles;

    /**
     * Flag indicating whether build configuration should be bypassed.
     */
    private String skip;

    /**
     * Gets the build information which shall be merged into the project.
     *
     * @return build information.
     */
    public BuildConfiguration getBuild()
    {
        return build;
    }

    /**
     * Gets default character encoding used to read property files. Character
     * encoding may be overridden for each loaded property file.
     *
     * @return default character encoding used to read property files.
     */
    @Override
    public String getDefaultPropertyFilesEncoding()
    {
        return defaultPropertyFilesEncoding;
    }

    @Override
    public List<DependencyConfiguration> getDependencies()
    {
        return dependencies;
    }

    /**
     * Gets the flag indicating whether the plugin should be quiet when a
     * property file is not found.
     *
     * @return flag indicating whether the plugin should be quiet.
     */
    @Override
    public String getIgnoreMissingPropertyFiles()
    {
        return ignoreMissingPropertyFiles;
    }

    @Override
    public List<PropertyFileConfiguration> getPropertyFiles()
    {
        return propertyFiles;
    }

    @Override
    public String getSkip()
    {
        return skip;
    }

    /**
     * Sets the build information which shall be merged into the project.
     *
     * @param build
     *            build information.
     */
    public void setBuild(final BuildConfiguration build)
    {
        this.build = build;
    }

    @Override
    public void setDefaultPropertyFilesEncoding(final String defaultPropertyFilesEncoding)
    {
        this.defaultPropertyFilesEncoding = defaultPropertyFilesEncoding;
    }

    @Override
    public void setDependencies(final List<DependencyConfiguration> dependencies)
    {
        this.dependencies = dependencies;
    }

    @Override
    public void setIgnoreMissingPropertyFiles(final String ignoreMissingPropertyFiles)
    {
        this.ignoreMissingPropertyFiles = ignoreMissingPropertyFiles;
    }

    @Override
    public void setPropertyFiles(final List<PropertyFileConfiguration> propertyFiles)
    {
        this.propertyFiles = propertyFiles;
    }

    @Override
    public void setSkip(final String skip)
    {
        this.skip = skip;
    }
}
