/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.core.configuration;

import java.util.List;

/**
 * Contains parameters for configuring a project.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public interface BuildConfiguratorPluginConfiguration
{
    /**
     * Gets default character encoding used to read property files. Character
     * encoding may be overridden for each loaded property file.
     *
     * @return default character encoding used to read property files.
     */
    String getDefaultPropertyFilesEncoding();

    /**
     * Gets the array of dependencies which shall be merged into the project.
     *
     * @return array of dependencies.
     */
    List<DependencyConfiguration> getDependencies();

    /**
     * Gets the flag indicating whether the plugin should be quiet when a
     * property file is not found.
     *
     * @return flag indicating whether the plugin should be quiet.
     */
    String getIgnoreMissingPropertyFiles();

    /**
     * Gets the array of property files whose properties shall be merged into
     * the project.
     *
     * @return array of property files.
     */
    List<PropertyFileConfiguration> getPropertyFiles();

    /**
     * Gets the flag indicating whether build configuration should be bypassed.
     *
     * @return flag indicating whether build configuration should be bypassed.
     */
    String getSkip();

    /**
     * Sets default character encoding used to read property files. Character
     * encoding may be overridden for each loaded property file.
     *
     * @param defaultPropertyFilesEncoding
     *            default character encoding used to read property files.
     */
    void setDefaultPropertyFilesEncoding(String defaultPropertyFilesEncoding);

    /**
     * Sets the array of dependencies which shall be merged into the project.
     *
     * @param dependencies
     *            array of dependencies.
     */
    void setDependencies(List<DependencyConfiguration> dependencies);

    /**
     * Sets the flag indicating whether the plugin should be quiet when a
     * property file is not found.
     *
     * @param ignoreMissingPropertyFiles
     *            flag indicating whether the plugin should be quiet.
     */
    void setIgnoreMissingPropertyFiles(String ignoreMissingPropertyFiles);

    /**
     * Sets the array of property files whose properties shall be merged into
     * the project.
     *
     * @param propertyFiles
     *            array of property files.
     */
    void setPropertyFiles(List<PropertyFileConfiguration> propertyFiles);

    /**
     * Sets the flag indicating whether build configuration should be bypassed.
     *
     * @param skip
     *            flag indicating whether build configuration should be
     *            bypassed.
     */
    void setSkip(String skip);
}
