/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.core.el;

import javax.el.ExpressionFactory;

/**
 * Contains utility methods for working with {@link ExpressionFactory}.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public abstract class DefaultExpressionFactory
{
    /**
     * Caches reference to the {@link ExpressionFactory} singleton.
     *
     * @author htfv (Aliaksei Lahachou)
     */
    private static class Singleton
    {
        /**
         * Reference to the {@link ExpressionFactory} singleton.
         */
        public static final ExpressionFactory INSTANCE = ExpressionFactory.newInstance();
    }

    /**
     * Returns reference to the {@link ExpressionFactory} singleton.
     *
     * @return reference to the {@link ExpressionFactory} singleton.
     *
     * @see ExpressionFactory#newInstance
     */
    public static ExpressionFactory getInstance()
    {
        return Singleton.INSTANCE;
    }
}
