/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.core.utils;

import javax.el.ELContext;

import com.github.htfv.maven.plugins.buildconfigurator.core.el.DefaultExpressionFactory;

/**
 * Contains utility methods for working with EL expressions.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public abstract class ELUtils
{
    /**
     * Evaluates EL value expression using default expression factory.
     *
     * @param elContext
     *            {@link ELContext} used to evaluate EL expressions.
     * @param expression
     *            the expression to evaluate.
     *
     * @return the result of the expression evaluation.
     */
    public static Boolean getBooleanValue(final ELContext elContext, final String expression)
    {
        return getValue(elContext, expression, Boolean.class);
    }

    /**
     * Evaluates EL value expression using default expression factory.
     *
     * @param elContext
     *            {@link ELContext} used to evaluate EL expressions.
     * @param expression
     *            the expression to evaluate.
     *
     * @return the result of the expression evaluation.
     */
    public static String getStringValue(final ELContext elContext, final String expression)
    {
        return getValue(elContext, expression, String.class);
    }

    /**
     * Evaluates EL value expression using default expression factory.
     *
     * @param <T>
     *            the type the result of the expression will be coerced to after
     *            evaluation.
     *
     * @param elContext
     *            {@link ELContext} used to evaluate EL expressions.
     * @param expression
     *            the expression to evaluate.
     * @param expectedType
     *            the type the result of the expression will be coerced to after
     *            evaluation.
     *
     * @return the result of the expression evaluation.
     */
    @SuppressWarnings("unchecked")
    public static <T> T getValue(final ELContext elContext, final String expression,
            final Class<T> expectedType)
    {
        if (expression == null)
        {
            return null;
        }

        return (T) DefaultExpressionFactory.getInstance()
                .createValueExpression(elContext, expression, expectedType)
                .getValue(elContext);
    }
}
